package cz.kebrt.unitcheck.api.data;

/**
 * Describes a failure that was caused by an uncaught exception.
 */
public class ExceptionFailure extends Failure {

    private final Throwable exception;
    private final String message;

    /**
     * Constructs an instance.
     *
     * @param exception exception that caused the failure
     * @param message message attached to the exception
     * @param description description of the failure
     * @param path execution trace leading to the failure
     * @param snapShot state of all threads at the moment of the failure
     */
    public ExceptionFailure(Description description, Throwable exception, String message,
            PathHolder path, String snapShot) {
        super(description, path, snapShot);
        this.exception = exception;
        this.message = message;
    }

    /**
     * Returns exception that caused the failure.
     *
     * @return exception that caused the failure
     */
    public Throwable getException() {
        return exception;
    }

    /**
     * Returns message attached to the exception.
     *
     * @return message attached to the exception
     */
    public String getMessage() {
        return message;
    }

}
