package cz.kebrt.unitcheck.console;

import org.kohsuke.args4j.Option;

/**
 * Options used by the command line UnitCheck program.
 *
 * @author michal
 */
class Options {

    @Option(name = "-b", aliases = { "--basedir" },
            usage = "unitcheck base directory", required = true)
    private String baseDir;

    @Option(name = "-t", aliases = { "--testclass" },
            usage = "JUnit test class to be checked", required = true)
    private String testClass;

    @Option(name = "-m", aliases = { "--testmethod" },
            usage = "JUnit test method in the test class to be tested\n")
    private String testMethod;

    @Option(name = "-c", aliases = { "--jpfconfig" },
            usage = "JPF config file to be used")
    private String jpfConfigFile;

    @Option(name = "-w", aliases = { "--nohaltonerror" },
            usage = "do not stop checking when error occurs")
    private boolean noHaltOnError = false;

    @Option(name = "-j", aliases = { "--nofilterjunit" },
            usage = "do not filter JUnit execution trace")
    private boolean noFilterJUnitTrace = false;

    @Option(name = "-e", aliases = { "--noexecutionhistory" },
            usage = "do not print execution history")
    private boolean noExecutionHistory = false;

    @Option(name = "-d", aliases = { "--bytecode" },
            usage = "print bytecode instructions")
    private boolean printBytecode = false;

    @Option(name = "-a", aliases = { "--tracejre" },
            usage = "trace JRE")
    private boolean traceJRE = false;

    @Option(name = "-p", aliases = { "--vmclasspath" },
            usage = "classpath to be used")
    private String vmClassPath;

    @Option(name = "-s", aliases = { "--vmsourcepath" },
            usage = "sourcepath to be used")
    private String vmSourcePath;

    public String getBaseDir() {
        return baseDir;
    }

    public String getTestClass() {
        return testClass;
    }

    public String getTestMethod() {
        return testMethod;
    }

    public String getJPFConfigFile() {
        return jpfConfigFile;
    }

    public boolean isNoHaltOnError() {
        return noHaltOnError;
    }

    public boolean isNoFilterJUnitTrace() {
        return noFilterJUnitTrace;
    }

    public boolean isNoExecutionHistory() {
        return noExecutionHistory;
    }

    public boolean isPrintBytecode() {
        return printBytecode;
    }

    public boolean isTraceJRE() {
        return traceJRE;
    }

    public String getVmClassPath() {
        return vmClassPath;
    }

    public String getVmSourcePath() {
        return vmSourcePath;
    }

}
