package cz.kebrt.unitcheck.junit;

import java.util.ArrayList;
import java.util.List;

import org.junit.runner.Description;
import org.junit.runner.manipulation.Filter;

/**
 * Filters test methods that will not be executed.
 *
 * @author michal
 */
class SingleTestFilter extends Filter {

    private List<String> allowedMethods = new ArrayList<String>();
    private List<String> allowedClasses = new ArrayList<String>();

    /**
     * Adds an item that will be executed.
     * @param arg string describing either a single test method or the
     *            whole test class
     */
    public void addAllowed(String arg) {
        if (arg.contains(SingleTestRunner.METHOD_DELIMITER)) {
            String[] split = arg.split(SingleTestRunner.METHOD_DELIMITER);
            allowedMethods.add(String.format("%s(%s)", split[1], split[0]));
            allowedMethods.add(split[0]);
        } else {
            allowedClasses.add(arg);
        }
    }

    @Override
    public String describe() {
        return this.getClass().getName();
    }

    @Override
    public boolean shouldRun(Description description) {
        for (String s : allowedClasses) {
            if (description.getDisplayName().contains(s)) {
                return true;
            }
        }
        for (String s : allowedMethods) {
            if (description.getDisplayName().equals(s)) {
                return true;
            }
        }
        return false;
    }

}
