package cz.kebrt.unitcheck.api.data;

/**
 * Describes a single execution step (i.e. a bytecode instruction generated from the
 * source code).
 */
public class StepHolder {

    private String line;
    private String location;
    private InstructionHolder instruction;

    /**
     * Constructs an instance.
     *
     * @param line line in the source code
     * @param location location of the source code (i.e. filename)
     * @param instruction executed bytecode instruction
     */
    public StepHolder(String line, String location, InstructionHolder instruction) {
        super();
        this.line = line;
        this.location = location;
        this.instruction = instruction;
    }

    /**
     * Returns line in the source code.
     * @return line in the source code
     */
    public String getLine() {
        return line;
    }

    /**
     * Returns location of the source code (i.e. filename).
     * @return location of the source code
     */
    public String getLocation() {
        return location;
    }

    /**
     * Returns executed bytecode instruction.
     * @return executed bytecode instruction
     */
    public InstructionHolder getInstruction() {
        return instruction;
    }

    @Override
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        if (!(o instanceof StepHolder)) {
            return false;
        }
        if (this.location == null) {
            return false;
        }
        if (this.line == null) {
            return false;
        }

        StepHolder that = (StepHolder) o;

        if (!this.location.equals(that.location)) {
            return false;
        }
        if (!this.line.equals(that.line)) {
            return false;
        }

        return true;
    }

    /**
    // TODO
    @Override
    public int hashCode() {
        return -1;
    }
    */

    /**
     * Returns <code>true</code> when two steps come from the same line in the source
     * code.
     *
     * @param o step which is compared with this step
     * @return <code>true</code> when two steps come from the same line in the source code
     */
    public boolean instructionPositionEquals(Object o) {
        if (o == null) {
            return false;
        }
        if (!(o instanceof StepHolder)) {
            return false;
        }

        StepHolder that = (StepHolder) o;

        if (that.instruction.getMethodName() == null) {
            return false;
        }
        if (that.instruction.getClassName() == null) {
            return false;
        }
        if (!that.instruction.getClassName().equals(this.instruction.getClassName())) {
            return false;
        }
        if (!that.instruction.getMethodName().equals(this.instruction.getMethodName())) {
            return false;
        }

        return true;
    }

}
