package cz.kebrt.unitcheck.junit;

import junit.framework.TestCase;

/**
 * Detects a version of JUnit test and returns corresponding method extractor.
 *
 * @author michal
 */
public final class VersionDetector {

    /**
     * JUnit version.
     */
    private enum Version {
        JUNIT3,
        JUNIT4
    };

    private VersionDetector() {
    }

    private static Version getVersion(Class<?> klass) {
        if (TestCase.class.isAssignableFrom(klass)) {
            return Version.JUNIT3;
        } else {
            return Version.JUNIT4;
        }
    }

    /**
     * Returns a test method extractor for the specified test class.
     *
     * @param klass JUnit test class
     * @return test method extractor for the specified test class
     */
    public static TestMethodExtractor getTestMethodExtractor(Class<?> klass) {
        Version version = getVersion(klass);
        switch (version) {
        case JUNIT3:
            return new JUnit3TestMethodExtractor(klass);
        case JUNIT4:
            return new JUnit4TestMethodExtractor(klass);
        default:
            return null;
        }
    }

}
