package cz.kebrt.unitcheck.util;

import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;

/**
 * Constructs a classpath to be used in <code>setContextClassLoader</code> calls.
 * Current classpath is used as a parent one.
 *
 * @author michal
 */
public final class ContextClassPathFactory {

    private static final String JAR_EXTENSION = ".jar"; //$NON-NLS-1$
    private static final String JUNIT_PREFIX = "org.junit";  //$NON-NLS-1$

    private ContextClassPathFactory() { }

    /**
     * Constructs a classpath.
     *
     * @param classpath elements to be placed in the classpath
     * @return returns classpath containing the specified elements
     * @throws IllegalStateException when classpath cannot be constructed
     */
    public static ClassLoader create(Iterable<String> classpath)
            throws IllegalStateException {
        try {
            List<URL> urls = new ArrayList<URL>();
            for (String s : classpath) {
                if (s.contains(JUNIT_PREFIX)) {
                    continue;
                }
                if (s.endsWith(JAR_EXTENSION)) {
                    urls.add(new URL("file:" + s)); //$NON-NLS-1$
                } else {
                    urls.add(new URL("file:" + s + "/")); //$NON-NLS-1$ //$NON-NLS-2$
                }
            }
            URLClassLoader classloader = new URLClassLoader(
                    urls.toArray(new URL[urls.size()]),
                    Thread.currentThread().getContextClassLoader());
            return classloader;
        } catch (MalformedURLException e) {
            throw new IllegalStateException(e);
        }
    }

}
